==> jc-1.4.0.tar.gz: java/awt/IllegalComponentStateException.h <==
// public class java.awt.IllegalComponentStateException

// class file dependencies
// @dep_class 5b9d43b385072dce java_awt_IllegalComponentStateException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class b7e704701c278e65 java_lang_IllegalStateException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_IllegalStateException

#include "java/lang/IllegalStateException.h"

#ifndef _JC_java_awt_IllegalComponentStateException_H_
#define _JC_java_awt_IllegalComponentStateException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_IllegalComponentStateException$sub_refs	_jc_java_awt_IllegalComponentStateException$sub_refs;
typedef struct _jc_java_awt_IllegalComponentStateException$sub_nonrefs	_jc_java_awt_IllegalComponentStateException$sub_nonrefs;
typedef struct _jc_java_awt_IllegalComponentStateException$refs	_jc_java_awt_IllegalComponentStateException$refs;
typedef struct _jc_java_awt_IllegalComponentStateException$nonrefs	_jc_java_awt_IllegalComponentStateException$nonrefs;
typedef struct _jc_java_awt_IllegalComponentStateException$object	_jc_java_awt_IllegalComponentStateException$object;

typedef struct _jc_java_awt_IllegalComponentStateException$fields_struct	_jc_java_awt_IllegalComponentStateException$fields_struct;
typedef const struct _jc_java_awt_IllegalComponentStateException$vmethods	_jc_java_awt_IllegalComponentStateException$vmethods;
typedef const struct _jc_java_awt_IllegalComponentStateException$vtable	_jc_java_awt_IllegalComponentStateException$vtable;
typedef const struct _jc_java_awt_IllegalComponentStateException$vtype	_jc_java_awt_IllegalComponentStateException$vtype;

// Class fields structure
struct _jc_java_awt_IllegalComponentStateException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_IllegalComponentStateException$fields_struct _jc_java_awt_IllegalComponentStateException$class_fields;

// Constructors
extern void _jc_java_awt_IllegalComponentStateException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_IllegalComponentStateException$object *);
extern void _jc_java_awt_IllegalComponentStateException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_IllegalComponentStateException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_awt_IllegalComponentStateException$vmethods {
};

// Vtable
struct _jc_java_awt_IllegalComponentStateException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalStateException$vmethods	java_lang_IllegalStateException;
	_jc_java_awt_IllegalComponentStateException$vmethods	java_awt_IllegalComponentStateException;
};

// Vtype
struct _jc_java_awt_IllegalComponentStateException$vtype {
	_jc_type			type;
	_jc_java_awt_IllegalComponentStateException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_IllegalComponentStateException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_IllegalComponentStateException$refs {
    _jc_java_awt_IllegalComponentStateException$sub_refs	java_awt_IllegalComponentStateException;
    _jc_java_lang_IllegalStateException$sub_refs	java_lang_IllegalStateException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_IllegalComponentStateException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_IllegalComponentStateException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalStateException$sub_nonrefs	java_lang_IllegalStateException;
    _jc_java_awt_IllegalComponentStateException$sub_nonrefs	java_awt_IllegalComponentStateException;
};

// Object instance structure
struct _jc_java_awt_IllegalComponentStateException$object {
	_jc_java_awt_IllegalComponentStateException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_IllegalComponentStateException$vtype	*vtype;
	_jc_java_awt_IllegalComponentStateException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_IllegalComponentStateException$vtype _jc_java_awt_IllegalComponentStateException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_IllegalComponentStateException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_IllegalComponentStateException$class_object;

#endif	/* _JC_java_awt_IllegalComponentStateException_H_ */

==> jc-1.4.6.tar.gz: java/awt/IllegalComponentStateException.h <==
// public class java.awt.IllegalComponentStateException

// class file dependencies
// @dep_class 5b9d43b385072dce java_awt_IllegalComponentStateException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class b7e704701c278e65 java_lang_IllegalStateException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_IllegalStateException

#include "java/lang/IllegalStateException.h"

#ifndef _JC_java_awt_IllegalComponentStateException_H_
#define _JC_java_awt_IllegalComponentStateException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_IllegalComponentStateException$sub_refs	_jc_java_awt_IllegalComponentStateException$sub_refs;
typedef struct _jc_java_awt_IllegalComponentStateException$sub_nonrefs	_jc_java_awt_IllegalComponentStateException$sub_nonrefs;
typedef struct _jc_java_awt_IllegalComponentStateException$refs	_jc_java_awt_IllegalComponentStateException$refs;
typedef struct _jc_java_awt_IllegalComponentStateException$nonrefs	_jc_java_awt_IllegalComponentStateException$nonrefs;
typedef struct _jc_java_awt_IllegalComponentStateException$object	_jc_java_awt_IllegalComponentStateException$object;

typedef struct _jc_java_awt_IllegalComponentStateException$fields_struct	_jc_java_awt_IllegalComponentStateException$fields_struct;
typedef const struct _jc_java_awt_IllegalComponentStateException$vmethods	_jc_java_awt_IllegalComponentStateException$vmethods;
typedef const struct _jc_java_awt_IllegalComponentStateException$vtable	_jc_java_awt_IllegalComponentStateException$vtable;
typedef const struct _jc_java_awt_IllegalComponentStateException$vtype	_jc_java_awt_IllegalComponentStateException$vtype;

// Class fields structure
struct _jc_java_awt_IllegalComponentStateException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_IllegalComponentStateException$fields_struct _jc_java_awt_IllegalComponentStateException$class_fields;

// Constructors
extern void _jc_java_awt_IllegalComponentStateException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_IllegalComponentStateException$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_IllegalComponentStateException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_awt_IllegalComponentStateException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_IllegalComponentStateException$vmethods {
};

// Vtable
struct _jc_java_awt_IllegalComponentStateException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalStateException$vmethods	java_lang_IllegalStateException;
	_jc_java_awt_IllegalComponentStateException$vmethods	java_awt_IllegalComponentStateException;
};

// Vtype
struct _jc_java_awt_IllegalComponentStateException$vtype {
	_jc_type			type;
	_jc_java_awt_IllegalComponentStateException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_IllegalComponentStateException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_IllegalComponentStateException$refs {
    _jc_java_awt_IllegalComponentStateException$sub_refs	java_awt_IllegalComponentStateException;
    _jc_java_lang_IllegalStateException$sub_refs	java_lang_IllegalStateException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_IllegalComponentStateException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_IllegalComponentStateException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalStateException$sub_nonrefs	java_lang_IllegalStateException;
    _jc_java_awt_IllegalComponentStateException$sub_nonrefs	java_awt_IllegalComponentStateException;
};

// Object instance structure
struct _jc_java_awt_IllegalComponentStateException$object {
	_jc_java_awt_IllegalComponentStateException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_IllegalComponentStateException$vtype	*vtype;
	_jc_java_awt_IllegalComponentStateException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_IllegalComponentStateException$vtype _jc_java_awt_IllegalComponentStateException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_IllegalComponentStateException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_IllegalComponentStateException$class_object;

#endif	/* _JC_java_awt_IllegalComponentStateException_H_ */
